

<!--
 * :Author: ChenXiaolei
 * :Date: 2020-12-09 14:35:01
 * @LastEditTime: 2021-01-06 15:02:49
 * @LastEditors: ChenXiaolei
 * :Description: 
-->
# seven_studio

## 天志互联Python公共基础后台管理平台

### 1.0.8 更新内容
* 增加腾讯云存储

### 1.0.6 更新内容
* 注释格式修改
* monitor迁移至内容管理平台基础框架

### 1.0.5 更新内容
* 增加oss2上传配置

### 1.0.3 更新内容
* 项目整理

### 1.0.2 更新内容
* 项目整理

### 1.0.1 更新内容
* bug修复

### 1.0.0 更新内容
* 项目创建